Learn R Programming

bluebike (version 0.0.3)

trip_distance: Compute trip distance for a specific dataset

Description

This function computes the geographical distance between the start and end stations for trips in a given dataset

Usage

trip_distance(data)

Arguments

data

trip data pulled from the Blue Bike System data

Value

a tbl_df object with an additional distance column

Examples

Run this code
# NOT RUN {
# Calculate distance for sample trip data
sample_distance <- trip_distance(trip_history_sample)$distance
# }

Run the code above in your browser using DataLab