powered by
This function computes the geographical distance between the start and end stations for trips in a given dataset
trip_distance(data)
trip data pulled from the Blue Bike System data
a tbl_df object with an additional distance column
# NOT RUN { # Calculate distance for sample trip data sample_distance <- trip_distance(trip_history_sample)$distance # }
Run the code above in your browser using DataLab